print.noia.multilinear <-
function (x, ...) 
{
    print.noia.common(x, ...)
}
